@@ -65,6 +65,11 @@ skip_dep_new_tibble_subclass <- function() {
   skip_legacy()
 }
 
+skip_dep_glimpse <- function() {
+  # DEP: glimpse() and format_v() now in pillar
+  skip_legacy()
+}
+
 skip_enh_posixlt_supported <- function() {
   # ENH: POSIXlt supported
   skip_legacy()
@@ -160,10 +165,14 @@ output_file <- function(filename) file.path("zzz-output", filename)
 expect_output_file_rel <- function(x, filename) {
   withr::with_options(
     list(digits = 4, width = 80, cli.unicode = l10n_info()$`UTF-8`),
-    expect_output_file(x, output_file(filename), update = TRUE)
+    suppressWarnings(expect_output_file(x, output_file(filename), update = TRUE))
   )
 }
 
 expect_output_knit <- function(knit, filename, envir = parent.frame()) {
   expect_output_file_rel(cat(knit), filename)
 }
+
+expect_output <- function(...) {
+  suppressWarnings(testthat::expect_output(...))
+}
